@@ -1,7 +1,7 @@
 import sys
 from pyspark.sql.functions import (when, col, trim, lit)
 from dnxdata.utils.utils import Utils
-from dnxdata.utils.s3 import s3
+from dnxdata.utils.s3 import S3
 from dnxdata.logger import Logger
 
 
@@ -12,20 +12,17 @@ class SparkUtils:
         self.spark = spark
         self.glue_context = glue_context
         self.utils = Utils()
-        self.s3 = s3()
+        self.s3 = S3()
 
-    def write_parquet(self, df, path, partition_column, mode, database, table, list_path_delete):
+    def write_parquet(self, df, path, partition_column, mode, database, table):
 
         self.logger.info("Starting write_parquet")
-        self.logger.info("Database + Table {}.{}".format(database, table))
+        self.logger.info("database.table => {}.{}".format(database, table))
 
         self.is_empty_df(df=df, exit_none=True)
 
         self.spark.catalog.setCurrentDatabase(database)
 
-        if len(list_path_delete) > 0:
-            self.s3.delete_file_s3(path=list_path_delete, path_or_key="path")
-
         write_obj = df.write. \
             format("parquet"). \
             option("path", path). \
@@ -138,7 +135,8 @@ class SparkUtils:
                 ),
                 "dbtable": connection_settings.get("dbtable"),
                 "user": connection_settings.get("user"),
-                "password": connection_settings.get("passwd")}
+                "password": connection_settings.get("passwd")
+            }
 
             df = self.glue_context.create_dynamic_frame.from_options(
                 connection_type=connection_type,
